ulaval_notify package — ulaval-notify 0.0.0 documentation

# ulaval_notify package

## Submodules

## ulaval_notify.constants module

`ulaval_notify.constants.` `SESSION_REFRESH_INTERVAL_IN_SECONDS` = 60

  The interval of time elapsed before the session is refreshed

## ulaval_notify.main module

This module contains the code related to the application execution.

copyright: | 2018 by Antoine Gagné.
license: | MIT, see LICENSE for more details.

`ulaval_notify.main.` `main`()

  The main entry point of the application.

## ulaval_notify.options module

`ulaval_notify.options.` `parse_arguments`()

  Create an `argparse.ArgumentParser` and parse the command-line arguments.

## ulaval_notify.utils module

class `ulaval_notify.utils.` `Decorator`

  Bases: `object`

  `wraps`(*args, **kwrags)

class `ulaval_notify.utils.` `before`(g, *args, **kwargs)

  Bases: `ulaval_notify.utils.Decorator`

  `wraps`(*args, **kwargs)

`ulaval_notify.utils.` `dummy_wrap`(f, *args, **kwargs)

`ulaval_notify.utils.` `run_as_daemon`(f, *args, **kwargs)

## Module contents